CURRENT PROJECT IS SAMPLE, SOURCED FROM PRABHAT MISHRA:
https://github.com/prabhatx/django-basic-project

Project Description:

This app will provide an educational infographic and personalized disaster preparation checklist based on a user's specific circumstance

Command for Build and Install:



Repository Link:

https://github.com/JMalegni/DisasterPrepApp

Run Command:


